@@ -27,7 +27,7 @@ function sendDM(tweet) {
         // var body1 = "status=" + encodeURIComponent(content);
         var bodylength = "status=" + content;
         var body = "text=" + url_encode(content.substring(3+user.length));
-        var xhr = createOAuthHeader("POST", "http://api.twitter.com/1/direct_messages/new.json", undefined, {"token":oauth.token, "secret":oauth.secret}, params,body);
+        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/direct_messages/new.json", undefined, {"token":oauth.token, "secret":oauth.secret}, params,body);
         xhr.onreadystatechange = function() {
             if (xhr.readyState == XMLHttpRequest.DONE) {
                //console.log("received: " + xhr.responseText);
@@ -59,7 +59,7 @@ function sendTweet(tweet, params) {
         // console.log("converted: " + body);
 
         // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
-        var xhr = createOAuthHeader("POST", "http://api.twitter.com/1/statuses/update.json", undefined, {"token":oauth.token, "secret":oauth.secret}, params,body);
+        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/statuses/update.json", undefined, {"token":oauth.token, "secret":oauth.secret}, params,body);
         xhr.onreadystatechange = function() {
             if (xhr.readyState == XMLHttpRequest.DONE) {
                //console.log("received: " + xhr.responseText);
@@ -85,7 +85,7 @@ function follow(username) {
         // console.log("converted: " + body);
 
         // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
-        var xhr = createOAuthHeader("POST", "http://api.twitter.com/1/friendships/create.xml", undefined, {"token":oauth.token, "secret":oauth.secret}, params);
+        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/friendships/create.xml", undefined, {"token":oauth.token, "secret":oauth.secret}, params);
         xhr.onreadystatechange = function() {
             if (xhr.readyState == XMLHttpRequest.DONE) {
                //console.log("received: " + xhr.responseText);
@@ -110,7 +110,7 @@ function unFollow(username) {
         // console.log("converted: " + body);
 
         // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
-        var xhr = createOAuthHeader("POST", "http://api.twitter.com/1/friendships/destroy.xml", undefined, {"token":oauth.token, "secret":oauth.secret}, params);
+        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/friendships/destroy.xml", undefined, {"token":oauth.token, "secret":oauth.secret}, params);
         xhr.onreadystatechange = function() {
             if (xhr.readyState == XMLHttpRequest.DONE) {
                //console.log("received: " + xhr.responseText);
